@@ -18,15 +18,18 @@ class MakeTestMovieFrames(WorkflowTaskBase, FitsDataMixin):
 
     def run(self):
         for d in range(1, self.constants.num_dsps_repeats + 1):
-            for path, hdu in self.fits_data_read_hdu(tags=[Tag.output(), Tag.dsps_repeat(d)]):
-                header = hdu.header
-                data = hdu.data
-                output_hdu = fits.PrimaryHDU(data=data, header=header)
-                output_hdul = fits.HDUList([output_hdu])
-                self.fits_data_write(
-                    hdu_list=output_hdul,
-                    tags=[Tag.movie_frame(), Tag.dsps_repeat(d)],
-                )
+            with self.apm_task_step(f"Workign on dsps repeat {d}"):
+                for path, hdu in self.fits_data_read_hdu(tags=[Tag.output(), Tag.dsps_repeat(d)]):
+                    header = hdu.header
+                    data = hdu.data
+                    output_hdu = fits.PrimaryHDU(data=data, header=header)
+                    output_hdul = fits.HDUList([output_hdu])
+
+                    with self.apm_writing_step("Writing data"):
+                        self.fits_data_write(
+                            hdu_list=output_hdul,
+                            tags=[Tag.movie_frame(), Tag.dsps_repeat(d)],
+                        )
 
 
 class AssembleTestMovie(AssembleMovie):
