@@ -14,12 +14,10 @@ from astropy.io import fits
 from dkist_data_simulator.spec122 import Spec122Dataset
 from dkist_header_validator import spec122_validator
 from dkist_processing_common._util.scratch import WorkflowFileSystem
-from dkist_processing_common.models.graphql import InputDatasetResponse
-from dkist_processing_common.models.graphql import RecipeInstanceResponse
-from dkist_processing_common.models.graphql import RecipeRunResponse
-from dkist_processing_common.models.graphql import RecipeRunStatusResponse
 from dkist_processing_common.models.tags import Tag
+from dkist_processing_common.tests.conftest import FakeGQLClient
 
+from dkist_processing_test.tasks.exercise_numba import ExerciseNumba
 from dkist_processing_test.tasks.fail import FailTask
 from dkist_processing_test.tasks.fake_science import GenerateCalibratedData
 from dkist_processing_test.tasks.movie import AssembleTestMovie
@@ -30,36 +28,6 @@ from dkist_processing_test.tests.conftest import generate_214_l0_fits_frame
 from dkist_processing_test.tests.conftest import S122Headers
 
 
-class FakeGQLClient:
-    def __init__(self, *args, **kwargs):
-        pass
-
-    @staticmethod
-    def execute_gql_query(**kwargs):
-        query_base = kwargs["query_base"]
-
-        if query_base == "recipeRunStatuses":
-            return [RecipeRunStatusResponse(recipeRunStatusId=1)]
-        if query_base == "recipeRuns":
-            return [
-                RecipeRunResponse(
-                    recipeInstanceId=1,
-                    recipeInstance=RecipeInstanceResponse(
-                        recipeId=1,
-                        inputDataset=InputDatasetResponse(
-                            inputDatasetId=1,
-                            isActive=True,
-                            inputDatasetDocument='{"bucket": "bucket-name", "parameters": [{"parameterName": "", "parameterValues": [{"parameterValueId": 1, "parameterValue": "[[1,2,3],[4,5,6],[7,8,9]]", "parameterValueStartDate": "1/1/2000"}]}], "frames": ["objectKey1", "objectKey2", "objectKeyN"]}',
-                        ),
-                    ),
-                )
-            ]
-
-    @staticmethod
-    def execute_gql_mutation(**kwargs):
-        pass
-
-
 @dataclass
 class FakeConstantDb:
     NUM_DSPS_REPEATS: int = 2
@@ -363,3 +331,24 @@ def test_assemble_test_movie_task(assemble_test_movie_task, mocker):
     logging.info(f"{movie_file=}")
     assert len(movie_file) == 1
     assert movie_file[0].exists()
+
+
+@pytest.fixture()
+def exercise_numba_task(recipe_run_id):
+    with ExerciseNumba(
+        recipe_run_id=recipe_run_id, workflow_name="ExerciseNumba", workflow_version="VX.Y"
+    ) as task:
+        yield task
+
+
+def test_exercise_numba_task(exercise_numba_task):
+    """
+    :Given: an exercise_numba task
+    :When: running the task
+    :Then: the numba module can be loaded and simple method using numba is executed
+    """
+    original = np.linspace(0.0, 10.0, 1001)
+    task = exercise_numba_task
+    task()
+    assert task.speedup > 1.0
+    assert np.all(np.equal(original, task.sorted_array))
